@@ -3,9 +3,9 @@ from ovos_skills_manager.appstores.andlo import AndloSkillList
 from ovos_skills_manager.appstores.mycroft_marketplace import MycroftMarketplace
 from ovos_skills_manager.appstores.pling import Pling
 from ovos_skills_manager.appstores.ovos import OVOSstore
+from ovos_skills_manager.appstores.neon import NeonSkills
+from ovos_skills_manager.appstores.local import InstalledSkills
 from ovos_skills_manager.osm import OVOSSkillsManager
 from ovos_utils.log import LOG
 
-LOG.set_level("INFO")
-
-
+LOG.set_level("INFO")
\ No newline at end of file
