@@ -1,22 +1,48 @@
-from json_database import JsonDatabaseXDG
+from json_database import JsonDatabaseXDG, JsonStorageXDG
 from json_database.search import Query
 from ovos_utils import create_daemon
 from ovos_utils.log import LOG
 from os.path import join, dirname, isfile
 from ovos_skills_manager import SkillEntry
+from ovos_skills_manager.exceptions import AuthenticationError
+from ovos_skills_manager.session import set_github_token, clear_github_token
+from ovos_skills_manager.github import get_branch_from_github_url,\
+    normalize_github_url, GithubInvalidBranch
 import shutil
+import re
 from os import remove
 
 
 class AbstractAppstore:
-    def __init__(self, name, parse_github=False):
+    def __init__(self, name, parse_github=False, appstore_id=None,
+                 bootstrap=False):
         self.name = name
+        default_id = re.sub(r'[^\w]', ' ',
+                            name.lower().replace("_", " ").replace("-", " "))
+        self.appstore_id = appstore_id or default_id
         self.db = JsonDatabaseXDG(name)
         self.parse_github = parse_github
-        self.bootstrap()
+        if bootstrap:
+            try:
+                self.bootstrap()
+            except AuthenticationError:
+                pass
 
-    def bootstrap(self):
-        base_db = join(dirname(dirname(__file__)), "res", "bootstrap_o",
+    def authenticate(self, auth_token=None, bootstrap=True):
+        if auth_token is None:
+            auth_token = JsonStorageXDG("OVOS-SkillsManager")["appstores"]\
+                .get(self.appstore_id, {}).get("auth_token")
+        if auth_token:
+            set_github_token(auth_token)
+            if bootstrap:
+                self.bootstrap()
+
+    @staticmethod
+    def clear_authentication():
+        clear_github_token()
+
+    def bootstrap(self, new_only=True):
+        base_db = join(dirname(dirname(__file__)), "res",
                        self.db.name + ".jsondb")
         if not len(self.db):
             LOG.info("Bootstrapping {database}, this might take a "
@@ -27,7 +53,7 @@ class AbstractAppstore:
                 self.db.reset()
             else:
                 LOG.debug("Downloading skill list")
-                self.sync_skills_list()
+                self.sync_skills_list(new_only=new_only)
 
     def clear_cache(self):
         if isfile(self.db.path):
@@ -73,21 +99,51 @@ class AbstractAppstore:
         results = query.result
         for idx in range(0, len(results)):
             if "appstore" not in results[idx]:
-                results[idx]["appstore"] = self.name
+                results[idx]["appstore"] = self.appstore_id
+
+        if as_json:
+            return query.result
+        return [SkillEntry.from_json(s, False) for s in results]
+
+    def search_skills_by_id(self, skill_id, as_json=False, fuzzy=False,
+                            thresh=0.85, ignore_case=True):
+        """ skill_id is repo.author , case insensitive,
+        searchs by name and filters results by author """
+        name = ".".join(skill_id.split(".")[:-1])
+        author = skill_id.rsplit('.', 1)[1]
+
+        query = Query(self.db)
+        query.contains_value('skillname', name, fuzzy, thresh, ignore_case)
+        query.value_contains_token('authorname', author, fuzzy, thresh,
+                                   ignore_case)
+        results = query.result
+        for idx in range(0, len(results)):
+            if "appstore" not in results[idx]:
+                results[idx]["appstore"] = self.appstore_id
+
         if as_json:
             return query.result
         return [SkillEntry.from_json(s, False) for s in results]
 
     def search_skills_by_url(self, url, as_json=False):
         query = Query(self.db)
-        query.equal("url", url)
+        try:
+            # if branch implicit in url, be sure to use it!
+            branch = get_branch_from_github_url(url)
+        except GithubInvalidBranch:
+            branch = None
+        url = normalize_github_url(url)
+        query.equal("url", url, ignore_case=True)
         results = query.result
         for idx in range(0, len(results)):
             if "appstore" not in results[idx]:
-                results[idx]["appstore"] = self.name
+                results[idx]["appstore"] = self.appstore_id
+            if branch:
+                # TODO what if branch does not exist? should throw exception
+                results[idx]["branch"] = branch
         if as_json:
             return query.result
-        return [SkillEntry.from_json(s, False) for s in results]
+        return [SkillEntry.from_json(s, parse_github=False) for s in results]
 
     def search_skills_by_category(self, category, as_json=False,
                                   fuzzy=True, thresh=0.85, ignore_case=True):
@@ -96,7 +152,7 @@ class AbstractAppstore:
         results = query.result
         for idx in range(0, len(results)):
             if "appstore" not in results[idx]:
-                results[idx]["appstore"] = self.name
+                results[idx]["appstore"] = self.appstore_id
         if as_json:
             return query.result
         return [SkillEntry.from_json(s, False) for s in results]
@@ -109,7 +165,7 @@ class AbstractAppstore:
         results = query.result
         for idx in range(0, len(results)):
             if "appstore" not in results[idx]:
-                results[idx]["appstore"] = self.name
+                results[idx]["appstore"] = self.appstore_id
         if as_json:
             return query.result
         return [SkillEntry.from_json(s, False) for s in results]
@@ -121,7 +177,7 @@ class AbstractAppstore:
         results = query.result
         for idx in range(0, len(results)):
             if "appstore" not in results[idx]:
-                results[idx]["appstore"] = self.name
+                results[idx]["appstore"] = self.appstore_id
         if as_json:
             return query.result
         return [SkillEntry.from_json(s, False) for s in results]
@@ -135,7 +191,7 @@ class AbstractAppstore:
         results = query.result
         for idx in range(0, len(results)):
             if "appstore" not in results[idx]:
-                results[idx]["appstore"] = self.name
+                results[idx]["appstore"] = self.appstore_id
         if as_json:
             return query.result
         return [SkillEntry.from_json(s, False) for s in results]
@@ -164,7 +220,7 @@ class AbstractAppstore:
                                                thresh, ignore_case)
         desc_skills = self.search_skills_by_description(query, as_json, fuzzy,
                                                         thresh, ignore_case)
-        res = desc_skills + tag_skills
+        res = desc_skills + tag_skills  # TODO: This may include duplicates DM
         if res:
             return res
 
