@@ -78,8 +78,9 @@ def get_mycroft_marketplace_skills(branch=None, parse_github=False,
 
 
 class MycroftMarketplace(AbstractAppstore):
-    def __init__(self, parse_github=False):
-        super().__init__("MycroftMarketplace", parse_github)
+    def __init__(self, *args, **kwargs):
+        super().__init__("MycroftMarketplace",
+                         appstore_id="mycroft_marketplace", *args, **kwargs)
 
     def get_skills_list(self, skiplist=None):
         return get_mycroft_marketplace_skills(
