@@ -2,13 +2,9 @@ import click
 from ovos_skills_manager import OVOSSkillsManager
 from pprint import pformat
 
-APPSTORE_OPTIONS = ["ovos", "mycroft", "pling", "andlo", "all", "default"]
+APPSTORE_OPTIONS = ["ovos", "mycroft", "pling", "andlo", "neon", "all", "default"]
 
 
-@click.command()
-@click.option('--appstore', default="all",
-              type=click.Choice(APPSTORE_OPTIONS),
-              help='print config of a specific appstore')
 def print_config(appstore):
     osm = OVOSSkillsManager()
     if appstore == "all":
