@@ -1,9 +1,10 @@
 import click
 from ovos_skills_manager import SkillEntry, OVOSSkillsManager
+from ovos_skills_manager.session import set_github_token
 
 SEARCH_OPTIONS = ['all', 'name', 'url', 'category', 'author', 'tag',
                   'description']
-APPSTORE_OPTIONS = ["ovos", "mycroft", "pling", "andlo", "default", "all"]
+APPSTORE_OPTIONS = ["ovos", "mycroft", "pling", "andlo", "neon", "default", "all"]
 
 
 def search_skill(method, query, fuzzy, no_ignore_case, thresh, appstore):
@@ -46,29 +47,6 @@ def search_skill(method, query, fuzzy, no_ignore_case, thresh, appstore):
     return skills
 
 
-@click.command()
-@click.option('--skill', prompt='skill to install (url or search term)',
-              help='skill to install')
-@click.option('--branch', type=str,
-              help='select skill github branch to use')
-@click.option('--folder', type=str, default="/opt/mycroft/skills",
-              help='path where skill will be installed, default /opt/mycroft/skills')
-@click.option('--search', default=False, is_flag=True,
-              help="search appstores, otherwise assume it's a github url")
-@click.option('--appstore', default="default",  # case_sensitive=False,
-              type=click.Choice(APPSTORE_OPTIONS),
-              help='search a specific appstore, default search '
-                   'appstores enabled in config file')
-@click.option('--method', default="all",  # case_sensitive=False,
-              type=click.Choice(SEARCH_OPTIONS),
-              help='match this metadata field when searching')
-@click.option('--fuzzy/--exact', default=True,
-              help='exact or fuzzy matching, default fuzzy')
-@click.option('--thresh', type=click.IntRange(0, 100, clamp=True), default=80,
-              help='fuzzy matching threshold from 0 (everything is a match) '
-                   'to 100 (exact match),  default 80')
-@click.option('--no-ignore-case', default=False, is_flag=True,
-              help='ignore upper/lower case, default ignore')
 def install(method, skill, fuzzy, no_ignore_case, thresh, appstore, search,
             branch, folder):
     if search:
