@@ -1,10 +1,13 @@
 import json
-from os.path import isfile, expanduser, join
+import shutil
+
+from os.path import isfile, expanduser, join, isdir
+
 from ovos_skills_manager.session import SESSION as requests
 from ovos_skills_manager.exceptions import GithubInvalidUrl, \
-    JSONDecodeError, GithubFileNotFound
+    JSONDecodeError, GithubFileNotFound, GithubInvalidBranch
 from ovos_skills_manager.github import download_url_from_github_url, \
-    get_branch, get_skill_data, get_requirements, get_desktop
+    get_branch, get_skill_data, get_requirements, get_branch_from_github_url
 from ovos_utils.json_helper import merge_dict
 from ovos_utils.skills import blacklist_skill, whitelist_skill, \
     make_priority_skill, get_skills_folder
@@ -12,13 +15,21 @@ from ovos_skill_installer import install_skill
 from ovos_skills_manager.requirements import install_system_deps, pip_install
 from ovos_utils.log import LOG
 from ovos_utils.enclosure import detect_enclosure
-import shutil
 
 
 class SkillEntry:
     def __init__(self, data=None):
         self._data = data or {}
 
+    @property
+    def uuid(self):
+        # a unique identifier
+        # github_repo.github_author , case insensitive
+        # should be guaranteed to be unique
+        author = self.skill_author.lower()
+        repo = self.skill_folder.lower()
+        return repo + "." + author
+
     @property
     def json(self):
         return self._data
@@ -30,8 +41,9 @@ class SkillEntry:
             if data.startswith("http"):
                 url = data
                 if "github" in url:
-                    # url parsed in github info step bellow
                     data = {"url": url}
+                    # repo is parsed in github info step below,
+                    # branch detected when parsing data dict
                 else:
                     try:
                         res = requests.get(url).text
@@ -52,9 +64,8 @@ class SkillEntry:
         if parse_github:
             url = data.get("url", "")
             if "github" in url:
-                branch = data.get("branch")
                 try:
-                    github_data = get_skill_data(url, branch)
+                    github_data = get_skill_data(url, data.get("branch"))
                     data = merge_dict(data, github_data, merge_lists=True,
                                       skip_empty=True, no_dupes=True)
                 except GithubInvalidUrl as e:
@@ -62,8 +73,9 @@ class SkillEntry:
         return SkillEntry(data)
 
     @staticmethod
-    def from_github_url(url, branch=None):
-        return SkillEntry.from_json({"url": url, "branch": branch}, True)
+    def from_github_url(url, branch=None, parse_github=True):
+        return SkillEntry.from_json({"url": url, "branch": branch},
+                                    parse_github=parse_github)
 
     # properties
     @property
@@ -128,13 +140,22 @@ class SkillEntry:
 
     @property
     def download_url(self):
+        """ provided in .json file """
         return self.json.get("download_url") or \
                download_url_from_github_url(self.url, self.branch)
 
+    @property
+    def default_download_url(self):
+        """ generated from github url directly"""
+        return download_url_from_github_url(self.url, self.branch)
+
     @property
     def requirements(self):
-        return self.json.get("requirements") or \
-               get_requirements(self.url, self.branch)
+        try:
+            return self.json.get("requirements") or \
+                   get_requirements(self.url, self.branch)
+        except GithubFileNotFound:
+            return {}
 
     @property
     def license(self):
@@ -169,7 +190,8 @@ class SkillEntry:
         return desktop_file
 
     def generate_readme(self):
-        template = """# <img src='{icon}' card_color='#000000' width='50' height='50' style='vertical-align:bottom'/> {title}
+        template = \
+            """# <img src='{icon}' card_color='#000000' width='50' height='50' style='vertical-align:bottom'/> {title}
 {one_liner}
 
 ## About
@@ -210,16 +232,19 @@ class SkillEntry:
         folder = folder or get_skills_folder()
         if self.download_url.endswith(".tar.gz"):
             ext = "tar.gz"
+        elif "zipball" in self.download_url:
+            ext = "zip"
         else:
             ext = self.download_url.split(".")[-1]
         file = self.skill_folder + "." + ext
-        # naming convention
-        skill_folder_name = ".".join([self.skill_name, self.skill_author])\
-            .lower().replace(" ", "-")
-        return install_skill(self.download_url, folder, file,
-                             skill_folder_name=skill_folder_name)
+        url = self.download_url
+        return install_skill(url, folder, file, session=requests,
+                             skill_folder_name=self.uuid)
 
-    def install(self, folder=None, default_branch="master", platform=None):
+    def install(self, folder=None, default_branch="master", platform=None,
+                update=True):
+        if not update and self.is_previously_installed(folder):
+            return False
         if self.branch_overrides:
             try:
                 platform = platform or detect_enclosure()
@@ -271,7 +296,7 @@ class SkillEntry:
                 content = requests.get(self.skill_icon).content
                 with open(icon_file, "wb") as f:
                     f.write(content)
-            else:
+            elif isfile(self.skill_icon):
                 shutil.copyfile(self.skill_icon, icon_file)
 
             # copy .desktop file
@@ -281,9 +306,13 @@ class SkillEntry:
 
         return updated
 
-    def update(self, folder=None):
+    def update(self, folder=None, default_branch="master", platform=None):
         # convenience method
-        return self.install(folder)
+        return self.install(folder, default_branch, platform, update=True)
+
+    def is_previously_installed(self, folder=None):
+        folder = folder or get_skills_folder()
+        return isdir(join(folder, self.uuid))
 
     def __repr__(self):
         return self.skill_name + " " + self.url
